@@ -41,6 +41,8 @@ commands_ = {
             "fbx dos     : Batching 'Density of States'."),
     'general': ('featurebox.cli.vasp_general_single',
                 "fbx general : Batching 'Vasprun.xml property'."),
+    'energy': ('featurebox.cli.vasp_general_single',
+                "fbx energy  : Batching 'free energy property'."),
     'diff': ('featurebox.cli.vasp_general_diff',
              "fbx diff    : Batching 'Energy difference'."),
     'converge': ('featurebox.cli.vasp_converge',
