@@ -8,7 +8,7 @@ from pymatgen.optimization.neighbors import find_points_in_spheres
 from featurebox.utils.predefined_typing import StructureOrMolecule
 
 
-def _re_pbc(pbc: Union[bool, List[bool], np.ndarray], return_type="bool"):
+def _re_pbc(pbc: Union[bool, List[bool], Tuple[bool], np.ndarray], return_type="bool"):
     if pbc is True:
         pbc = [1, 1, 1]
     elif pbc is False:
@@ -27,7 +27,7 @@ def _re_pbc(pbc: Union[bool, List[bool], np.ndarray], return_type="bool"):
 def get_radius_in_spheres(
         structure: StructureOrMolecule, nn_strategy=None, cutoff: float = 5.0,
         numerical_tol: float = 1e-6,
-        pbc=True,
+        pbc: Union[bool, Tuple[bool]] = True,
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
     """
     Get graph representations from structure within cutoff.
@@ -69,16 +69,15 @@ def get_radius_in_spheres(
     exclude_self = (distances > numerical_tol)
     # exclude_self = (center_indices != neighbor_indices) | (distances > numerical_tol)
 
-    return center_indices[exclude_self], neighbor_indices[exclude_self], distances[exclude_self].reshape(-1, 1), \
-           distances[exclude_self], np.array(np.NaN)
+    return center_indices[exclude_self], neighbor_indices[exclude_self], \
+           distances[exclude_self].reshape(-1, 1), distances[exclude_self], np.array(np.NaN)
 
-
-if __name__ == "__main__":
-    from mgetool.tool import tt
-
-    structure = Structure.from_file("../../data/temp_test_structure/W2C.cif")
-    tt.t
-    get_points_ = get_radius_in_spheres(structure,
-                                        cutoff=5.0, )
-    tt.t  #
-    tt.p
+# if __name__ == "__main__":
+#     from mgetool.tool import tt
+#
+#     structure = Structure.from_file("../../data/temp_test_structure/W2C.cif")
+#     tt.t
+#     get_points_ = get_radius_in_spheres(structure,
+#                                         cutoff=5.0, )
+#     tt.t  #
+#     tt.p
